// Acclromtre LIS3D
// (Ne fonctionne que sur la premire version des cartes MSP4-EXP430F5529 )
// EPFL 2020, Pierre-Yves Rochat, pyr@pyr.ch

#include <msp430.h>
#include <stdint.h>

#include "HAL_LIS3DH.h"

#include <HAL_Dogs102x6.h>

#include <PYR_CarteBlanche.h>
#include <PYR_5PWM.h>

#define AMPLIF_X 2
#define AMPLIF_Y 4
#define AMPLIF_Z 4

int16_t offsetX, offsetY, offsetZ;

void LIS3D_calibre() {
  uint16_t i;
  offsetX = 0; offsetY = 0; offsetZ = 0;
  for (i=0; i<100; i++){ // Attente pour stabiliser le capteur (?)
    while(debCycle==0) {} // synchronise avec le cycle du PWM
    debCycle = 0;
  }
  for (i=0; i<16; i++){ // moyenne sur 16 valeurs
    while(debCycle==0) {} // synchronise avec le cycle du PWM
    debCycle = 0;
    LIS3DH_readAccel();
    offsetX += LIS3DH_xAccel;
    offsetY += LIS3DH_yAccel;
    offsetZ += LIS3DH_zAccel;
  }
  offsetX = offsetX/16; offsetY = offsetY/16; offsetZ = offsetZ/16;
}

void main(void) {
  WDTCTL = WDTPW | WDTHOLD;
  setupDCO(); // Frquence  25 MHz
  InitCarteBlanche();
  InitPWM();

  LIS3DH_init(); // Init acclromtre

  Dogs102x6_init(); Dogs102x6_backlightInit(); // Init LCD
  Dogs102x6_setBacklight(11); Dogs102x6_setContrast(11);

  uint16_t cpt = 0; // compteur de cycles
  uint16_t x = 0; // coordonne sur l'afficheur
  int16_t accX, accY, accZ;
  LIS3D_calibre();

  while (1) { // boucle infinie
    if (x==0) { // vide l'cran et affiche les axes X et Y
      Dogs102x6_clearScreen();
      Dogs102x6_verticalLineDraw(0, 30, 0, 0);
      Dogs102x6_charDraw(0, 2, 'x', 0);
      Dogs102x6_verticalLineDraw(32, 62, 0, 0);
      Dogs102x6_charDraw(4, 2, 'y', 0);
    }
    while(debCycle==0) {} // synchronise avec le cycle du PWM
    debCycle = 0;
    LIS3DH_readAccel(); // lecture des 3 acclrations
    accX = LIS3DH_xAccel-offsetX;
    accY = LIS3DH_yAccel-offsetY;
    accZ = LIS3DH_zAccel-offsetZ;

    // Acclration en X en PWM sur LED5 (positif) et LED6 (ngatif):
    if (accX>=0) { pwm5 = accX*128*AMPLIF_X; pwm6 = 0; } else { pwm6 = -accX*128*AMPLIF_X; pwm5 = 0; }
    // Acclration en Y en PWM sur LED7 (positif) et LED8 (ngatif):
    if (accY>=0) { pwm7 = accY*128*AMPLIF_Y; pwm8 = 0; } else { pwm8 = -accY*128*AMPLIF_Y; pwm7 = 0; }
    // Acclration en Z en PWM sur LED4 (valeur absolue):
    if (accZ>=0) { pwm4 = accZ*128*AMPLIF_Z; } else { pwm4 = -accZ*128*AMPLIF_Z; }
    if (accZ>10) { Led1On; } else { Led1Off; } // LED rouge : Z vers le bas
    if (accZ<-10) { Led3On; } else { Led3Off; } // LED verte : z bers le haut

    cpt++;
    if (cpt == 50) { // plot X et Y sur l'afficheur (une valeur tous les 50 cycles)
      cpt = 0;
      Dogs102x6_pixelDraw(x, 16-(accX/2), 0); // amplitude de +-16 sur la moiti du haut
      Dogs102x6_pixelDraw(x, 48-(accY/2), 0); // amplitude de +-16 sur la moiti du bas
      x++;
      if (x==DOGS102x6_X_SIZE) { x = 0; } // limite droite de l'afficheur (102 pixels)
    }
  }
}


